@@ -343,7 +343,7 @@ void
 _PyCFunction_DebugMallocStats(FILE *out)
 {
     _PyDebugAllocatorStats(out,
-                           "free PyCFunctionObjects",
+                           "free PyCFunctionObject",
                            numfree, sizeof(PyCFunctionObject));
 }
 
